Module arrow_c

Module arrow_c 

Arrow C Data Interface import helpers.

These helpers provide a narrow bridge from raw Arrow C pointers to the runtime DataTable representation.

Functions

datatable_from_arrow_c_ptrs
Build a DataTable from raw pointers to Arrow C interface structs.
datatable_from_arrow_ffi
Build a DataTable from owned Arrow C interface structs.