datatable_from_arrow_c_ptrs

Function datatable_from_arrow_c_ptrs 

pub unsafe fn datatable_from_arrow_c_ptrs(
    schema_ptr: usize,
    array_ptr: usize,
) -> Result<DataTable, String>
Build a DataTable from raw pointers to Arrow C interface structs.

Safety

  • schema_ptr must point to a valid initialized FFI_ArrowSchema.
  • array_ptr must point to a valid initialized FFI_ArrowArray.
  • This function takes ownership of both values via ptr::read.