Closure support for Shape functions
Structs
- Captured
Binding - A captured variable binding
- Captured
Environment - Captured environment for a closure
- Closure
- A closure captures a function definition along with its environment
- Environment
Analyzer - Environment analyzer to detect which variables need to be captured