Module code_search

Module code_search 

Structural code search over content-addressed function blobs.

Enables querying functions by signature, dependency patterns, instruction patterns, and structural properties.

Structs

CodeIndex
A searchable index over a set of function blobs.
FunctionQuery
Query for searching functions.
IndexedFunction
Indexed metadata about a function.
SearchResult
Result of a code search query.