pub struct CodeIndex { /* private fields */ }Expand description
A searchable index over a set of function blobs.
Implementations
Sourceimpl CodeIndex
impl CodeIndex
Sourcepub fn index_function(
&mut self,
hash: [u8; 32],
name: String,
arity: u16,
instruction_count: usize,
dependencies: Vec<[u8; 32]>,
type_schemas: Vec<String>,
is_async: bool,
is_closure: bool,
captures_count: u16,
)
pub fn index_function( &mut self, hash: [u8; 32], name: String, arity: u16, instruction_count: usize, dependencies: Vec<[u8; 32]>, type_schemas: Vec<String>, is_async: bool, is_closure: bool, captures_count: u16, )
Add a function to the index.
Sourcepub fn search(&self, query: &FunctionQuery) -> SearchResult
pub fn search(&self, query: &FunctionQuery) -> SearchResult
Execute a query against the index, returning all functions that match every specified criterion.
Sourcepub fn find_callers(&self, function_hash: [u8; 32]) -> Vec<IndexedFunction>
pub fn find_callers(&self, function_hash: [u8; 32]) -> Vec<IndexedFunction>
Find functions that call the given function hash (i.e. have it as a dependency).
Sourcepub fn find_callees(&self, function_hash: [u8; 32]) -> Vec<IndexedFunction>
pub fn find_callees(&self, function_hash: [u8; 32]) -> Vec<IndexedFunction>
Find functions called by the given function hash (its direct dependencies).
Sourcepub fn dependency_depth(&self, function_hash: [u8; 32]) -> Option<usize>
pub fn dependency_depth(&self, function_hash: [u8; 32]) -> Option<usize>
Compute the transitive dependency depth for a function.
Returns None if the function is not in the index.
A function with no dependencies has depth 0.
A function that calls only leaf functions has depth 1, etc.
Cycles are detected and treated as already-visited (depth 0 contribution).