Module columnar_aggregations

Module columnar_aggregations 

SIMD-optimized aggregations for columnar object series

Uses the wide crate for portable SIMD that works on stable Rust and automatically selects AVX2/SSE2/NEON based on target platform.

Functions

count_valid_f64
Count non-NaN values in a numeric column
max_f64_column
Find maximum value in a numeric column using SIMD
max_f64_slice
Maximum of a raw f64 slice using SIMD.
mean_f64_column
Calculate mean of a numeric column using SIMD sum
mean_f64_slice
Mean of a raw f64 slice using SIMD sum.
min_f64_column
Find minimum value in a numeric column using SIMD
min_f64_slice
Minimum of a raw f64 slice using SIMD.
sum_f64_column
Sum a numeric column using portable SIMD
sum_f64_slice
Sum a raw f64 slice using portable SIMD.