Module keychain

Module keychain 

Trusted author keychain for module signature verification.

The Keychain stores a set of trusted Ed25519 public keys with associated trust levels, and provides verification of module signatures against the trust policy.

Structs

Keychain
A keychain managing trusted author keys and module signature verification.
TrustedAuthor
A trusted author entry in the keychain.

Enums

TrustLevel
How much trust is granted to a particular author key.
VerifyResult
Result of verifying a module against the keychain.