Module signing

Module signing 

Ed25519 digital signature support for module manifests.

Provides signing and verification of content-addressed module manifests using Ed25519 key pairs.

Structs

ModuleSignatureData
Cryptographic signature data attached to a module manifest.

Functions

generate_keypair
Generate a new Ed25519 signing/verifying key pair.
generate_keypair_bytes
Generate a new Ed25519 key pair, returning raw byte arrays.
public_key_from_secret
Get the public key bytes for a given secret key.
sign_manifest_hash
Sign a manifest hash using raw secret key bytes (32 bytes).