Generic DataFrame for columnar time series data
Industry-agnostic storage for any time series data with named columns.
Structs
- Data
Frame - Generic columnar storage for time series data
- DataRow
- A borrowed view of a single row in a DataFrame
- Owned
Data Row - An owned data row with generic fields