pub struct EngineBootstrapState {
pub semantic: SemanticSnapshot,
pub context: ExecutionContext,
}Expand description
Snapshot of preloaded engine state (semantic + runtime context).
This is used by services (e.g. shape-server) to avoid reloading stdlib from disk on every request while still creating an isolated engine per run.
Fields
semantic: SemanticSnapshotcontext: ExecutionContextTrait Implementations
Sourceimpl Clone for EngineBootstrapState
impl Clone for EngineBootstrapState
Sourcefn clone(&self) -> EngineBootstrapState
fn clone(&self) -> EngineBootstrapState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for EngineBootstrapState
impl !RefUnwindSafe for EngineBootstrapState
impl Send for EngineBootstrapState
impl Sync for EngineBootstrapState
impl Unpin for EngineBootstrapState
impl UnsafeUnpin for EngineBootstrapState
impl !UnwindSafe for EngineBootstrapState