pub fn format_error_message(kind: &ParseErrorKind) -> StringExpand description
Format the main error message based on error kind (plain text, no colors)
pub fn format_error_message(kind: &ParseErrorKind) -> StringFormat the main error message based on error kind (plain text, no colors)