pub fn convert_pest_error(
pest_error: &Error<Rule>,
source: &str,
) -> StructuredParseErrorExpand description
Convert a pest error into a structured parse error
pub fn convert_pest_error(
pest_error: &Error<Rule>,
source: &str,
) -> StructuredParseErrorConvert a pest error into a structured parse error