pub struct ExecutionProof {
pub function_hash: [u8; 32],
pub args_hash: [u8; 32],
pub result_hash: [u8; 32],
pub timestamp: u64,
pub trace: Option<Vec<[u8; 32]>>,
pub proof_hash: [u8; 32],
}Expand description
A cryptographic proof that a function was executed with given inputs producing given outputs.
Fields
function_hash: [u8; 32]Content hash of the function that was executed.
args_hash: [u8; 32]SHA-256 hash of the serialized arguments.
result_hash: [u8; 32]SHA-256 hash of the serialized result.
timestamp: u64Unix timestamp (seconds) when execution completed.
trace: Option<Vec<[u8; 32]>>Optional execution trace: hashes of intermediate states.
proof_hash: [u8; 32]Hash of this entire proof (excluding this field).
Implementations
Sourceimpl ExecutionProof
impl ExecutionProof
Sourcepub fn compute_proof_hash(
function_hash: &[u8; 32],
args_hash: &[u8; 32],
result_hash: &[u8; 32],
timestamp: u64,
trace: &Option<Vec<[u8; 32]>>,
) -> [u8; 32]
pub fn compute_proof_hash( function_hash: &[u8; 32], args_hash: &[u8; 32], result_hash: &[u8; 32], timestamp: u64, trace: &Option<Vec<[u8; 32]>>, ) -> [u8; 32]
Compute a deterministic hash over all proof fields except proof_hash itself.
Sourcepub fn verify_integrity(&self) -> bool
pub fn verify_integrity(&self) -> bool
Verify that the proof’s proof_hash matches its contents.