pub struct ProofRegistry { /* private fields */ }Expand description
Registry of execution proofs, indexed by function hash.
Implementations
Sourceimpl ProofRegistry
impl ProofRegistry
Sourcepub fn register(&mut self, proof: ExecutionProof) -> usize
pub fn register(&mut self, proof: ExecutionProof) -> usize
Register a proof. Returns the index of the newly registered proof.
Sourcepub fn lookup(&self, function_hash: &[u8; 32]) -> &[ExecutionProof]
pub fn lookup(&self, function_hash: &[u8; 32]) -> &[ExecutionProof]
Look up all proofs for a given function content hash.
Sourcepub fn lookup_iter<'a>(
&'a self,
function_hash: &[u8; 32],
) -> impl Iterator<Item = &'a ExecutionProof>
pub fn lookup_iter<'a>( &'a self, function_hash: &[u8; 32], ) -> impl Iterator<Item = &'a ExecutionProof>
Iterate over all proofs for a given function hash.
Sourcepub fn verify_all(&self) -> Vec<(usize, VerificationResult)>
pub fn verify_all(&self) -> Vec<(usize, VerificationResult)>
Verify integrity of all registered proofs.
Returns a list of (proof_index, VerificationResult) for every proof
that fails integrity verification.