pub fn create_convolution_intrinsics_module() -> ModuleExportsExpand description
Create the convolution intrinsics module with the single typed-marshal
entry point __intrinsic_stencil.
pub fn create_convolution_intrinsics_module() -> ModuleExportsCreate the convolution intrinsics module with the single typed-marshal
entry point __intrinsic_stencil.