Module leakage

Module leakage 

Lookahead bias and data leakage detection

This module provides heuristic detection of common simulation mistakes:

  • Using current element data for events and executing at same index
  • Insufficient warmup periods for stateful functions
  • Using future information in calculations

These are “honest defaults” that warn users about potential simulation flaws.

Structs

LeakageDetector
Detector for leakage in a simulation
LeakageReport
LeakageWarning
A single leakage warning

Enums

LeakageSeverity
Leakage warning severity
LeakageType
Types of leakage detected