pub struct ModuleParam {
pub name: String,
pub type_name: String,
pub required: bool,
pub description: String,
pub default_snippet: Option<String>,
pub allowed_values: Option<Vec<String>>,
pub nested_params: Option<Vec<ModuleParam>>,
}Expand description
Schema for a single parameter of a module function. Used by LSP for completions and by validation for type checking.
Fields
name: Stringtype_name: Stringrequired: booldescription: Stringdefault_snippet: Option<String>allowed_values: Option<Vec<String>>nested_params: Option<Vec<ModuleParam>>Trait Implementations
Sourceimpl Clone for ModuleParam
impl Clone for ModuleParam
Sourcefn clone(&self) -> ModuleParam
fn clone(&self) -> ModuleParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleParam
impl Debug for ModuleParam