Module alignment

Module alignment 

Multi-table alignment and joining

Functions

align_intersection
Aligns multiple row sets to their intersection of timestamps
align_left
Aligns one row set to a reference row set (left join)
align_tables
Aligns right rows to match the timestamps of left rows
align_union
Aligns multiple row sets to the union of all timestamps
join_tables
Joins two row sets by timestamp (inner join)