pub fn align_left(
left: &[OwnedDataRow],
right: &[OwnedDataRow],
) -> Result<Vec<OwnedDataRow>>Expand description
Aligns one row set to a reference row set (left join)
pub fn align_left(
left: &[OwnedDataRow],
right: &[OwnedDataRow],
) -> Result<Vec<OwnedDataRow>>Aligns one row set to a reference row set (left join)