pub fn align_tables(
left_rows: &[OwnedDataRow],
right_rows: &[OwnedDataRow],
_timeframe: Timeframe,
) -> Result<Vec<OwnedDataRow>>Expand description
Aligns right rows to match the timestamps of left rows
pub fn align_tables(
left_rows: &[OwnedDataRow],
right_rows: &[OwnedDataRow],
_timeframe: Timeframe,
) -> Result<Vec<OwnedDataRow>>Aligns right rows to match the timestamps of left rows