pub fn align_union(
series_data: &[Vec<OwnedDataRow>],
) -> Result<Vec<Vec<OwnedDataRow>>>Expand description
Aligns multiple row sets to the union of all timestamps
pub fn align_union(
series_data: &[Vec<OwnedDataRow>],
) -> Result<Vec<Vec<OwnedDataRow>>>Aligns multiple row sets to the union of all timestamps