Multiple testing corrections and warnings
This module provides tools to track the number of parameter combinations tested during optimization and warn about overfitting risks.
Structs
- Multiple
Testing Guard - Guard that tracks and warns about multiple testing
- Multiple
Testing Stats - Statistics about multiple testing
Enums
- Correction
Method - Multiple testing correction methods
- Warning
Level - Warning severity level