Module language_runtime

Module language_runtime 

Language runtime capability wrapper (shape.language_runtime).

Wraps a loaded LanguageRuntimeVTable plugin to provide foreign function compilation and invocation for inline foreign language blocks.

Structs

CompiledForeignFunction
Handle to a compiled foreign function within a language runtime.
PluginLanguageRuntime
Wrapper around a loaded language runtime extension.
RuntimeLspConfig
Host-consumable LSP configuration declared by a language runtime extension.