pub struct ProgressRegistry { /* private fields */ }Expand description
Global registry for progress events
Uses a lock-free queue for event storage and broadcast channel for real-time subscribers.
Implementations
Sourceimpl ProgressRegistry
impl ProgressRegistry
Sourcepub fn start_operation(
self: &Arc<Self>,
source: &str,
granularity: ProgressGranularity,
) -> ProgressHandle
pub fn start_operation( self: &Arc<Self>, source: &str, granularity: ProgressGranularity, ) -> ProgressHandle
Start a new operation and return a handle for reporting progress
Sourcepub fn subscribe(&self) -> Receiver<ProgressEvent>
pub fn subscribe(&self) -> Receiver<ProgressEvent>
Subscribe to real-time progress events
Sourcepub fn poll(&self) -> Option<ProgressEvent>
pub fn poll(&self) -> Option<ProgressEvent>
Poll for a single event (non-blocking)
Sourcepub fn poll_all(&self) -> Vec<ProgressEvent>
pub fn poll_all(&self) -> Vec<ProgressEvent>
Poll all available events (non-blocking)
Sourcepub fn try_recv(&self) -> Option<ProgressEvent>
pub fn try_recv(&self) -> Option<ProgressEvent>
Try to receive a single event (non-blocking, alias for poll)