pub fn parse_shape_project_toml(content: &str) -> Result<ShapeProject, Error>Expand description
Parse a shape.toml document into a ShapeProject.
This is the single source of truth for manifest parsing across CLI, runtime, and tooling.
pub fn parse_shape_project_toml(content: &str) -> Result<ShapeProject, Error>Parse a shape.toml document into a ShapeProject.
This is the single source of truth for manifest parsing across CLI, runtime, and tooling.