Module query_builder

Module query_builder 

Query plan and SQL generation for data source pushdown.

Provides a standalone query plan data structure and SQL generator. Used by DbTable and other Queryable implementations to build queries that can be pushed down to the data source.

Structs

QueryPlan
A query plan that accumulates operations for SQL generation.

Functions

filter_to_sql
Generate SQL for a FilterNode
literal_to_sql
Generate SQL for a FilterLiteral