pub struct SimulationEngine { /* private fields */ }Expand description
Generic simulation engine for event-driven processing
Implementations
Sourceimpl SimulationEngine
impl SimulationEngine
Sourcepub fn new(config: SimulationEngineConfig) -> Self
pub fn new(config: SimulationEngineConfig) -> Self
Create a new simulation engine with the given configuration
Sourcepub fn default_config() -> Self
pub fn default_config() -> Self
Create with default configuration
Sourcepub fn run<F>(
&self,
data: &[ValueWord],
handler: F,
) -> Result<SimulationEngineResult>
pub fn run<F>( &self, data: &[ValueWord], handler: F, ) -> Result<SimulationEngineResult>
Run simulation over a sequence of values
The handler is called for each value with (value, current_state, index) and returns a StepResult containing the new state and any events.
Sourcepub fn run_with_hooks<F, Pre, Post>(
&self,
data: &[ValueWord],
pre_process: Pre,
handler: F,
post_process: Post,
) -> Result<SimulationEngineResult>where
F: Fn(&ValueWord, &ValueWord, usize) -> Result<StepResult>,
Pre: Fn(&ValueWord) -> Result<ValueWord>,
Post: Fn(SimulationEngineResult) -> Result<SimulationEngineResult>,
pub fn run_with_hooks<F, Pre, Post>(
&self,
data: &[ValueWord],
pre_process: Pre,
handler: F,
post_process: Post,
) -> Result<SimulationEngineResult>where
F: Fn(&ValueWord, &ValueWord, usize) -> Result<StepResult>,
Pre: Fn(&ValueWord) -> Result<ValueWord>,
Post: Fn(SimulationEngineResult) -> Result<SimulationEngineResult>,
Run simulation with pre-processing and post-processing hooks