Parallel Parameter Sweeps
This module provides parallel execution utilities for running multiple simulations with different parameter sets using rayon for parallelization.
Structs
- Parallel
Sweep Result - Result of a parallel parameter sweep.
Functions
- par_run
- Run a parameter sweep in parallel using rayon.
- par_
run_ with_ config - Run a parameter sweep with custom DenseKernelConfig.
- param_
grid - Build a 2D parameter grid.
- param_
grid3 - Build a 3D parameter grid.