pub fn create_env_module() -> ModuleExportsExpand description
Create the env module with environment variable and system info functions.
pub fn create_env_module() -> ModuleExportsCreate the env module with environment variable and system info functions.