io_tcp_read

Function io_tcp_read 

pub fn io_tcp_read(
    args: &[ValueWord],
    ctx: &ModuleContext<'_>,
) -> Result<ValueWord, String>
io.tcp_read(handle, n?) -> string

Read from a TCP stream. If n is given, read up to n bytes; otherwise read whatever is available in a single recv (up to 64KB).