Module type_methods

Module type_methods 

Type method registry for storing user-defined methods on types

This module provides the infrastructure for storing and retrieving methods that have been added to types via the extend statement.

Structs

TypeMethodRegistry
Registry for storing type methods