pub struct TypeMethodRegistry { /* private fields */ }Expand description
Registry for storing type methods
Implementations
Sourceimpl TypeMethodRegistry
impl TypeMethodRegistry
Sourcepub fn register_method(&self, type_name: &TypeName, method: MethodDef)
pub fn register_method(&self, type_name: &TypeName, method: MethodDef)
Register a method for a type
Sourcepub fn get_methods(
&self,
type_name: &str,
method_name: &str,
) -> Option<Vec<MethodDef>>
pub fn get_methods( &self, type_name: &str, method_name: &str, ) -> Option<Vec<MethodDef>>
Get all methods for a type with a given name
Sourcepub fn get_value_type_name(value: &ValueWord) -> String
pub fn get_value_type_name(value: &ValueWord) -> String
Get the type name for a value
Sourcepub fn get_all_methods(&self, type_name: &str) -> Vec<MethodDef>
pub fn get_all_methods(&self, type_name: &str) -> Vec<MethodDef>
Get all methods for a type
Sourcepub fn get_registered_types(&self) -> Vec<String>
pub fn get_registered_types(&self) -> Vec<String>
Get all registered type names
Sourcepub fn debug_state(&self) -> String
pub fn debug_state(&self) -> String
Get a debug string representation of the registry state