Intersection type support for type schemas
This module provides functionality for merging multiple type schemas into intersection types (A + B), with field collision detection.
Intersection type support for type schemas
This module provides functionality for merging multiple type schemas into intersection types (A + B), with field collision detection.