Module schema

Module schema 

Core TypeSchema struct and methods

This module defines the TypeSchema structure that describes the memory layout of a declared type, with computed field offsets for JIT optimization.

Structs

TypeBinding
Mapping from TypeSchema field indices to Arrow column indices.
TypeSchema
Schema describing the memory layout of a declared type

Enums

TypeBindingError
Error during type binding to Arrow schema.