Module checker

Module checker 

Type Checker

Performs type checking on Shape programs using the type inference engine and reports type errors with helpful messages.

Structs

TypeCheckResult
Result of type checking
TypeChecker
TypeWarning
Type warning for non-fatal issues

Enums

TypeAnalysisMode

Functions

analyze_program
Shared single-entry type analysis used by compiler and LSP.
analyze_program_with_mode
Shared type analysis with explicit recovery behavior.
quick_check
Quick type check for REPL and testing
type_of_expr
Type check an expression and return its type