Unifier

Struct Unifier 

pub struct Unifier { /* private fields */ }

Implementations

Source

impl Unifier

pub fn new() -> Self

pub fn bind(&mut self, var: TypeVar, ty: Type)

Bind a type variable to a type

pub fn lookup(&self, var: &TypeVar) -> Option<&Type>

Look up a type variable’s binding

pub fn apply_substitutions(&self, ty: &Type) -> Type

Apply substitutions to a type

pub fn apply_to_annotation(&self, ann: &TypeAnnotation) -> TypeAnnotation

Apply substitutions to a type annotation

pub fn merge(&mut self, other: &Unifier)

Merge another unifier’s substitutions

pub fn clear(&mut self)

Clear all substitutions

pub fn substitutions(&self) -> &HashMap<TypeVar, Type>

Get all substitutions

pub fn try_unify(&self, t1: &Type, t2: &Type) -> Result<(), ()>

Try to unify two types without modifying this unifier’s state

Returns Ok(()) if the types can be unified, Err otherwise. This is useful for soft constraints in bidirectional type checking.