Extensions to the AST for flexible query execution
This module proposes enhanced query structures that support Shape-defined rules for analysis and backtesting.
Structs
- Analyze
Clause - Analyze clause with Shape-defined rules
- Find
Clause - Find clause that identifies pattern matches
- Output
Clause - Output clause for formatting results
- Process
Rules - Process
Statement - Process statement for unified execution This is the new primary way to execute analysis and backtesting
- State
Block - State
Declaration
Enums
- Pattern
Reference - Pattern reference for AST extensions
- Process
Target