Module binary_reader

Module binary_reader 

Binary reader for converting binary columnar data to DataTable

Reads binary data produced by plugins and converts it to DataTable. Helper functions for reading typed columns from binary format are available for use by the DataTable migration.

Functions

read_binary_to_datatable
Read binary columnar data and convert to a DataTable.