Structural code search over content-addressed function blobs.
Enables querying functions by signature, dependency patterns, instruction patterns, and structural properties.
Structs
- Code
Index - A searchable index over a set of function blobs.
- Function
Query - Query for searching functions.
- Indexed
Function - Indexed metadata about a function.
- Search
Result - Result of a code search query.