SIMD-optimized aggregations for columnar object series
Uses the wide crate for portable SIMD that works on stable Rust
and automatically selects AVX2/SSE2/NEON based on target platform.
Functions
- count_
valid_ f64 - Count non-NaN values in a numeric column
- max_
f64_ column - Find maximum value in a numeric column using SIMD
- max_
f64_ slice - Maximum of a raw f64 slice using SIMD.
- mean_
f64_ column - Calculate mean of a numeric column using SIMD sum
- mean_
f64_ slice - Mean of a raw f64 slice using SIMD sum.
- min_
f64_ column - Find minimum value in a numeric column using SIMD
- min_
f64_ slice - Minimum of a raw f64 slice using SIMD.
- sum_
f64_ column - Sum a numeric column using portable SIMD
- sum_
f64_ slice - Sum a raw f64 slice using portable SIMD.