Content method dispatch for ContentNode instance methods.
Provides method handler functions for ContentNode values. These follow the
same signature pattern as other method handlers in the codebase: they receive
a receiver (the ContentNode) + args as Vec<ValueWord> and return Result<ValueWord>.
Methods:
- Style:
fg(color),bg(color),bold(),italic(),underline(),dim() - Table:
border(style),max_rows(n) - Chart:
series(label, data),title(s),x_label(s),y_label(s)
Functions
- call_
content_ method - Look up and call a content method by name.