call_content_method

Function call_content_method 

pub fn call_content_method(
    method_name: &str,
    receiver: ValueWord,
    args: Vec<ValueWord>,
) -> Option<Result<ValueWord>>
Look up and call a content method by name.

Returns Some(result) if the method was found, None if not recognized.