Module dataframe

Module dataframe 

Generic DataFrame for columnar time series data

Industry-agnostic storage for any time series data with named columns.

Structs

DataFrame
Generic columnar storage for time series data
DataRow
A borrowed view of a single row in a DataFrame
OwnedDataRow
An owned data row with generic fields