pub struct ShapeEngineBuilder { /* private fields */ }Expand description
Builder pattern for creating an engine with configuration
Implementations
Sourceimpl ShapeEngineBuilder
impl ShapeEngineBuilder
pub fn new() -> Self
pub fn with_data(self, data: DataFrame) -> Self
Sourcepub fn with_async_provider(self, provider: SharedAsyncProvider) -> Self
pub fn with_async_provider(self, provider: SharedAsyncProvider) -> Self
Set async data provider (Phase 6)
When using an async provider, the engine will prefetch data before execution. This enables concurrent data loading and live data streaming.
pub fn enable_debug(self, enable: bool) -> Self
pub fn max_execution_time(self, duration: Duration) -> Self
pub fn memory_limit(self, bytes: usize) -> Self
pub fn build(self) -> Result<ShapeEngine>