Module loading and management for Shape
This module handles loading, compiling, and caching Shape modules from both the standard library and user-defined sources.
Structs
- Filesystem
Resolver - Filesystem resolver using standard module path rules.
- InMemory
Resolver - In-memory resolver used for embedded stdlib and extension modules.
- Module
- A compiled module ready for execution
- Module
Export Symbol - Exported symbol metadata used by tooling (LSP, analyzers).
- Module
Loader - Module loader manages loading and caching of modules
- Resolved
Module Artifact - A resolved module artifact with optional filesystem origin metadata.
Enums
- Export
- An exported item from a module
- Module
Code - Resolved module payload content.
- Module
Export Kind - Kind of exported symbol discovered from module source.
Constants
- EMBEDDED_
STDLIB_ MODULES - Embedded
std::...modules (module path, source).
Traits
- Module
Resolver - Trait implemented by all module resolvers.
Functions
- collect_
exported_ function_ names_ from_ source - Collect exported function names from module source using canonical module-loader export semantics.
- collect_
exported_ symbols - Collect exported symbols from a parsed module AST using runtime export semantics.
- resolve_
module_ path_ with_ settings - Canonical module resolution entrypoint shared by runtime, VM, and tooling.