Package bundle format for distributable .shapec files
A package bundle contains pre-compiled bytecode for all modules in a Shape package, plus metadata for versioning and freshness checks.
File format: [8 bytes "SHAPEPKG"] [4 bytes format_version LE] [MessagePack payload]
Structs
- Bundle
Metadata - Metadata about a compiled package bundle.
- Bundled
Module - A single compiled module within a bundle.
- Bundled
Native Dependency Scope - Native dependency scope embedded in a
.shapecbundle. - Package
Bundle - A compiled package bundle containing all modules and metadata.