Module pattern_library

Module pattern_library 

Pattern library stub for semantic analysis

Patterns are now loaded from Shape files, not hardcoded. This is a minimal stub to satisfy the semantic analyzer.

Structs

PatternLibrary