pub struct PluginLoader { /* private fields */ }Expand description
Plugin Loader
Manages dynamic loading and unloading of Shape plugins. Keeps loaded libraries in memory to prevent unloading while in use.
Implementations
Sourceimpl PluginLoader
impl PluginLoader
Sourcepub fn load(&mut self, path: &Path) -> Result<LoadedPlugin>
pub fn load(&mut self, path: &Path) -> Result<LoadedPlugin>
Sourcepub fn get_data_source_vtable(
&self,
name: &str,
) -> Result<&'static DataSourceVTable>
pub fn get_data_source_vtable( &self, name: &str, ) -> Result<&'static DataSourceVTable>
Sourcepub fn get_output_sink_vtable(
&self,
name: &str,
) -> Result<&'static OutputSinkVTable>
pub fn get_output_sink_vtable( &self, name: &str, ) -> Result<&'static OutputSinkVTable>
Sourcepub fn get_module_vtable(&self, name: &str) -> Result<&'static ModuleVTable>
pub fn get_module_vtable(&self, name: &str) -> Result<&'static ModuleVTable>
Get the base module vtable for a loaded plugin.
Sourcepub fn get_language_runtime_vtable(
&self,
name: &str,
) -> Result<&'static LanguageRuntimeVTable>
pub fn get_language_runtime_vtable( &self, name: &str, ) -> Result<&'static LanguageRuntimeVTable>
Get the language runtime vtable for a loaded plugin.
Sourcepub fn unload(&mut self, name: &str) -> bool
pub fn unload(&mut self, name: &str) -> bool
Unload a plugin
Note: The library is actually unloaded when dropped. This removes it from the loader’s tracking.
Sourcepub fn loaded_plugins(&self) -> Vec<&str>
pub fn loaded_plugins(&self) -> Vec<&str>
List all loaded plugins
Sourcepub fn load_data_source(
&mut self,
path: &Path,
config: &Value,
) -> Result<PluginDataSource>
pub fn load_data_source( &mut self, path: &Path, config: &Value, ) -> Result<PluginDataSource>
Load a data source plugin and return a ready-to-use wrapper
This is a convenience method that combines loading the library, getting the vtable, and creating the PluginDataSource wrapper.
Arguments
path- Path to the shared libraryconfig- Configuration value for the plugin
Returns
Ready-to-use PluginDataSource wrapper