High-level query execution API for Shape
This module provides the main interface for executing Shape queries against data and generating results with statistics.
Structs
- Execution
Metadata - Metadata about query execution
- Pattern
Match - A single pattern match result
- Performance
Metrics - Generic metrics for pattern matches
- Query
Executor - Main query executor that orchestrates the entire Shape pipeline
- Query
Result - Result of executing a Shape query
- Query
Statistics - Statistics about query results
- Time
Distribution - Time distribution of pattern matches
- Time
Range - Time range information
Enums
- Query
Type - Types of Shape queries