pub enum Type {
Show 21 variants
Number,
String,
Bool,
Null,
Unit,
Color,
Timestamp,
Timeframe,
TimeRef,
Duration,
Pattern,
Object(Vec<(String, Type)>),
Array(Box<Type>),
Matrix(Box<Type>),
Column(Box<Type>),
Function {
params: Vec<Type>,
returns: Box<Type>,
},
Module,
Range(Box<Type>),
Result(Box<Type>),
Unknown,
Error,
}Expand description
Types in the Shape type system
Variants
Number
Numeric type (float)
String
String type
Bool
Boolean type
Null
Null type
Unit
Unit type (void/no value)
Color
Bar color type
Timestamp
Timestamp type (point in time, epoch milliseconds)
Timeframe
Timeframe type
TimeRef
Time reference
Duration
Duration type
Pattern
Pattern reference
Object(Vec<(String, Type)>)
Object type with field types
Array(Box<Type>)
Array type
Matrix(Box<Type>)
Matrix type
Column(Box<Type>)
Column type (vectorized column operations)
Function
Function type
Module
Module type
Range(Box<Type>)
Range type (for iteration)
Result(Box<Type>)
Result type (fallible operations) Contains the Ok type; Error type is universal
Unknown
Unknown type (for type inference)
Error
Error type
Implementations
Sourceimpl Type
impl Type
Sourcepub fn can_coerce_to(&self, other: &Type) -> bool
pub fn can_coerce_to(&self, other: &Type) -> bool
Check if this type can be coerced to another type
Sourcepub fn binary_op_result(&self, op: &BinaryOp, rhs: &Type) -> Type
pub fn binary_op_result(&self, op: &BinaryOp, rhs: &Type) -> Type
Get the result type of a binary operation
Sourcepub fn unary_op_result(&self, op: &UnaryOp) -> Type
pub fn unary_op_result(&self, op: &UnaryOp) -> Type
Get the result type of a unary operation
Sourcepub fn property_type(&self, property: &str) -> Type
pub fn property_type(&self, property: &str) -> Type
Get the type of a property access
Sourcepub fn to_inference_type(&self) -> Type
pub fn to_inference_type(&self) -> Type
Convert legacy semantic Type to inference Type
This bridges the legacy type checker’s type representation to the modern inference engine’s type system.
Sourcepub fn from_inference_type(ty: &Type) -> Self
pub fn from_inference_type(ty: &Type) -> Self
Convert inference Type to legacy semantic Type
This bridges the modern inference engine’s type system back to the legacy type checker’s type representation.