Module parallel

Module parallel 

Parallel Parameter Sweeps

This module provides parallel execution utilities for running multiple simulations with different parameter sets using rayon for parallelization.

Structs

ParallelSweepResult
Result of a parallel parameter sweep.

Functions

par_run
Run a parameter sweep in parallel using rayon.
par_run_with_config
Run a parameter sweep with custom DenseKernelConfig.
param_grid
Build a 2D parameter grid.
param_grid3
Build a 3D parameter grid.