pub fn block_on_shared<F, T>(future: F) -> Result<T>Expand description
Block on a future using the shared runtime
This is safe to call from synchronous contexts as it properly handles nested runtime calls by using the handle instead of entering the runtime.