Type method registry for storing user-defined methods on types
This module provides the infrastructure for storing and retrieving
methods that have been added to types via the extend statement.
Structs
- Type
Method Registry - Registry for storing type methods