Type Checker
Performs type checking on Shape programs using the type inference engine and reports type errors with helpful messages.
Structs
- Type
Check Result - Result of type checking
- Type
Checker - Type
Warning - Type warning for non-fatal issues
Enums
Functions
- analyze_
program - Shared single-entry type analysis used by compiler and LSP.
- analyze_
program_ with_ mode - Shared type analysis with explicit recovery behavior.
- quick_
check - Quick type check for REPL and testing
- type_
of_ expr - Type check an expression and return its type