Error Suggestions
Provides “did you mean?” suggestions for type errors using Levenshtein distance to find similar names when users make typos.
Functions
- find_
similar - Find similar strings from a list of candidates.
- format_
suggestion - Format a “did you mean?” suggestion.
- levenshtein_
distance - Calculate the Levenshtein edit distance between two strings.
- reasonable_
max_ distance - Calculate a reasonable max distance for suggestions based on target length.
- suggest_
function - Suggestion for an undefined function.
- suggest_
property - Suggestion for an unknown property.
- suggest_
variable - Suggestion for an undefined variable.